#!/usr/bin/env python
"""
This example demonstrates how to use the FUN3D python interfaces to
update the properties of the 7011 boundary condition.
"""
import numpy as np
from mpi4py import MPI
from fun3d.solvers import Flow
from fun3d import interface
import f90nml


def get_total_pressure_ratio(step):
    """
    arbitrary sinusoidal variation of total pressure
    """
    pressure_ratio = 1.35 + 0.2 * np.sin(2.0 * np.pi * float(step) / 500.0)
    return pressure_ratio


def get_total_temperature_ratio(step):
    """
    arbitrary sinusoidal variation of total temperature
    """
    temperature_ratio = 1.05 + 0.04 * np.sin(2.0 * np.pi * float(step) / 500.0)
    return temperature_ratio


def main():
    comm = MPI.COMM_WORLD
    flow = Flow()

    nml = f90nml.read("fun3d.nml")
    nsteps = nml["code_run_control"]["steps"]

    # if restarting set to number of steps in the restart file
    prior_steps = 0

    # limited support for options typically read from command line. See list at top of Python/flow/interface.py
    command_line_options = {}
    flow.initialize(kwargs=command_line_options, comm=comm)

    for step in range(prior_steps + 1, prior_steps + 1 + nsteps):

        ibc = 1  # corresponds to BC 7011 in the mapbc file
        pressure_ratio = get_total_pressure_ratio(step)
        interface.bc_input_total_pressure_ratio(ibc, pressure_ratio)

        temperature_ratio = get_total_temperature_ratio(step)
        interface.bc_input_total_temperature_ratio(ibc, temperature_ratio)

        flow.iterate()
    flow.post()


if __name__ == "__main__":
    main()
